/* ISC license. */

#include <skalibs/tai.h>

tain const tain_nano500 = TAIN_NANO500 ;
